@@ -1,5 +1,5 @@
 /*
- *  Copyright © 2017-2023 Wellington Wallace
+ *  Copyright © 2017-2024 Wellington Wallace
  *
  *  This file is part of Easy Effects.
  *
@@ -19,11 +19,17 @@
 
 #pragma once
 
+#include <STTypes.h>
 #include <adwaita.h>
 #include <fmt/core.h>
+#include <gio/gio.h>
+#include <glib-object.h>
+#include <glibconfig.h>
+#include <gtk/gtkbox.h>
+#include <gtk/gtkicontheme.h>
+#include <unordered_map>
 #include "application.hpp"
-#include "node_info_holder.hpp"
-#include "tags_resources.hpp"
+#include "pipe_objects.hpp"
 
 namespace ui::app_info {
 
