@@ -1,5 +1,5 @@
 /*
- *  Copyright © 2017-2023 Wellington Wallace
+ *  Copyright © 2017-2024 Wellington Wallace
  *
  *  This file is part of Easy Effects.
  *
@@ -20,10 +20,14 @@
 #pragma once
 
 #include <adwaita.h>
+#include <gio/gio.h>
+#include <glib-object.h>
+#include <glib.h>
 #include <glib/gi18n.h>
-#include <string>
+#include <glibconfig.h>
+#include <sigc++/connection.h>
+#include <vector>
 #include "pipe_manager.hpp"
-#include "preferences_window.hpp"
 #include "presets_manager.hpp"
 #include "stream_input_effects.hpp"
 #include "stream_output_effects.hpp"
