@@ -30,7 +30,8 @@ class BassEnhancer : public PluginBase {
   BassEnhancer(const std::string& tag,
                const std::string& schema,
                const std::string& schema_path,
-               PipeManager* pipe_manager);
+               PipeManager* pipe_manager,
+               PipelineType pipe_type);
   BassEnhancer(const BassEnhancer&) = delete;
   auto operator=(const BassEnhancer&) -> BassEnhancer& = delete;
   BassEnhancer(const BassEnhancer&&) = delete;
