@@ -1,5 +1,5 @@
 /*
- *  Copyright © 2017-2023 Wellington Wallace
+ *  Copyright © 2017-2024 Wellington Wallace
  *
  *  This file is part of Easy Effects.
  *
@@ -19,8 +19,10 @@
 
 #pragma once
 
-#include <gtk/gtk.h>
-#include "pipe_manager.hpp"
+#include <glib-object.h>
+#include <glibconfig.h>
+#include <sigc++/signal.h>
+#include "pipe_objects.hpp"
 
 namespace ui::holders {
 
