@@ -35,7 +35,8 @@ class Convolver : public PluginBase {
   Convolver(const std::string& tag,
             const std::string& schema,
             const std::string& schema_path,
-            PipeManager* pipe_manager);
+            PipeManager* pipe_manager,
+            PipelineType pipe_type);
   Convolver(const Convolver&) = delete;
   auto operator=(const Convolver&) -> Convolver& = delete;
   Convolver(const Convolver&&) = delete;
@@ -53,7 +54,14 @@ class Convolver : public PluginBase {
 
   bool do_autogain = false;
 
+  const std::string irs_ext = ".irs";
+
+  auto search_irs_path(const std::string& name) -> std::string;
+
  private:
+  std::string local_dir_irs;
+  std::vector<std::string> system_data_dir_irs;
+
   bool kernel_is_initialized = false;
   bool n_samples_is_power_of_2 = true;
   bool zita_ready = false;
