@@ -1,5 +1,5 @@
 /*
- *  Copyright © 2017-2023 Wellington Wallace
+ *  Copyright © 2017-2024 Wellington Wallace
  *
  *  This file is part of Easy Effects.
  *
@@ -19,13 +19,10 @@
 
 #pragma once
 
-#include <adwaita.h>
-#include <execution>
-#include <numeric>
-#include "convolver_ui_common.hpp"
-#include "resampler.hpp"
-#include "tags_resources.hpp"
-#include "ui_helpers.hpp"
+#include <glib-object.h>
+#include <glibconfig.h>
+#include <gtk/gtk.h>
+#include <string>
 
 namespace ui::convolver_menu_combine {
 
