@@ -1,5 +1,5 @@
 /*
- *  Copyright © 2017-2023 Wellington Wallace
+ *  Copyright © 2017-2024 Wellington Wallace
  *
  *  This file is part of Easy Effects.
  *
@@ -20,19 +20,13 @@
 #pragma once
 
 #include <adwaita.h>
-#include <fftw3.h>
-#include <gsl/gsl_spline.h>
-#include <algorithm>
-#include <mutex>
-#include <numbers>
-#include <ranges>
+#include <glib-object.h>
+#include <glibconfig.h>
+#include <gtk/gtkbox.h>
+#include <memory>
+#include <string>
 #include "application.hpp"
-#include "chart.hpp"
-#include "convolver_menu_combine.hpp"
-#include "convolver_menu_impulses.hpp"
-#include "effects_base.hpp"
-#include "tags_resources.hpp"
-#include "ui_helpers.hpp"
+#include "convolver.hpp"
 
 namespace ui::convolver_box {
 
