@@ -1,5 +1,5 @@
 /*
- *  Copyright © 2017-2023 Wellington Wallace
+ *  Copyright © 2017-2024 Wellington Wallace
  *
  *  This file is part of Easy Effects.
  *
@@ -20,8 +20,9 @@
 #pragma once
 
 #include <filesystem>
-#include <sndfile.hh>
-#include "util.hpp"
+#include <string>
+#include <tuple>
+#include <vector>
 
 namespace ui::convolver {
 
