@@ -1,5 +1,5 @@
 /*
- *  Copyright © 2017-2023 Wellington Wallace
+ *  Copyright © 2017-2024 Wellington Wallace
  *
  *  This file is part of Easy Effects.
  *
@@ -20,9 +20,12 @@
 #pragma once
 
 #include <adwaita.h>
-#include "effects_base.hpp"
-#include "tags_resources.hpp"
-#include "ui_helpers.hpp"
+#include <glib-object.h>
+#include <glibconfig.h>
+#include <gtk/gtkbox.h>
+#include <memory>
+#include <string>
+#include "crystalizer.hpp"
 
 namespace ui::crystalizer_box {
 
