@@ -27,7 +27,11 @@
 
 class Deesser : public PluginBase {
  public:
-  Deesser(const std::string& tag, const std::string& schema, const std::string& schema_path, PipeManager* pipe_manager);
+  Deesser(const std::string& tag,
+          const std::string& schema,
+          const std::string& schema_path,
+          PipeManager* pipe_manager,
+          PipelineType pipe_type);
   Deesser(const Deesser&) = delete;
   auto operator=(const Deesser&) -> Deesser& = delete;
   Deesser(const Deesser&&) = delete;
