@@ -1,5 +1,5 @@
 /*
- *  Copyright © 2017-2023 Wellington Wallace
+ *  Copyright © 2017-2024 Wellington Wallace
  *
  *  This file is part of Easy Effects.
  *
@@ -19,8 +19,10 @@
 
 #pragma once
 
+#include <gio/gio.h>
+#include <nlohmann/json_fwd.hpp>
 #include "plugin_preset_base.hpp"
-#include "tags_equalizer.hpp"
+#include "preset_type.hpp"
 
 class EqualizerPreset : public PluginPresetBase {
  public:
