@@ -26,7 +26,11 @@
 
 class Filter : public PluginBase {
  public:
-  Filter(const std::string& tag, const std::string& schema, const std::string& schema_path, PipeManager* pipe_manager);
+  Filter(const std::string& tag,
+         const std::string& schema,
+         const std::string& schema_path,
+         PipeManager* pipe_manager,
+         PipelineType pipe_type);
   Filter(const Filter&) = delete;
   auto operator=(const Filter&) -> Filter& = delete;
   Filter(const Filter&&) = delete;
