@@ -1,5 +1,5 @@
 /*
- *  Copyright © 2017-2023 Wellington Wallace
+ *  Copyright © 2017-2024 Wellington Wallace
  *
  *  This file is part of Easy Effects.
  *
@@ -19,10 +19,9 @@
 
 #pragma once
 
-#include <iostream>
+#include <gtk/gtk.h>
 #include "libportal-gtk4/portal-gtk4.h"
 #include "libportal/portal.h"
-#include "ui_helpers.hpp"
 
 namespace libportal {
 
