@@ -29,7 +29,7 @@ G_BEGIN_DECLS
 
 #define EE_TYPE_PREFERENCES_WINDOW (preferences_window_get_type())
 
-G_DECLARE_FINAL_TYPE(PreferencesWindow, preferences_window, EE, PREFERENCES_WINDOW, AdwPreferencesWindow)
+G_DECLARE_FINAL_TYPE(PreferencesWindow, preferences_window, EE, PREFERENCES_WINDOW, AdwPreferencesDialog)
 
 G_END_DECLS
 
