@@ -39,7 +39,11 @@
 
 class RNNoise : public PluginBase {
  public:
-  RNNoise(const std::string& tag, const std::string& schema, const std::string& schema_path, PipeManager* pipe_manager);
+  RNNoise(const std::string& tag,
+          const std::string& schema,
+          const std::string& schema_path,
+          PipeManager* pipe_manager,
+          PipelineType pipe_type);
   RNNoise(const RNNoise&) = delete;
   auto operator=(const RNNoise&) -> RNNoise& = delete;
   RNNoise(const RNNoise&&) = delete;
@@ -57,15 +61,22 @@ class RNNoise : public PluginBase {
 
   void init_release();
 
+  auto search_model_path(const std::string& name) -> std::string;
+
 #ifndef ENABLE_RNNOISE
   bool package_installed = false;
 #endif
 
+  const std::string rnnn_ext = ".rnnn";
+
   bool standard_model = true;
 
   sigc::signal<void(const bool load_error)> model_changed;
 
  private:
+  std::string local_dir_rnnoise;
+  std::vector<std::string> system_data_dir_rnnoise;
+
   bool resample = false;
   bool notify_latency = false;
   bool rnnoise_ready = false;
@@ -99,7 +110,7 @@ class RNNoise : public PluginBase {
   float vad_prob_left, vad_prob_right;
   int vad_grace_left, vad_grace_right;
 
-  auto get_model_from_file() -> RNNModel*;
+  auto get_model_from_name() -> RNNModel*;
 
   void free_rnnoise();
 
