@@ -29,6 +29,10 @@ inline constexpr auto icons = "/com/github/wwmm/easyeffects/icons";
 
 inline constexpr auto css = "/com/github/wwmm/easyeffects/ui/custom.css";
 
+// Flatpak info file
+
+inline constexpr auto flatpak_info_file = "/.flatpak-info";
+
 // Path to the widgets xml files
 
 inline constexpr auto app_info_ui = "/com/github/wwmm/easyeffects/ui/app_info.ui";
@@ -119,6 +123,8 @@ inline constexpr auto preferences_window_ui = "/com/github/wwmm/easyeffects/ui/p
 
 inline constexpr auto preset_row_ui = "/com/github/wwmm/easyeffects/ui/preset_row.ui";
 
+inline constexpr auto preset_row_community_ui = "/com/github/wwmm/easyeffects/ui/preset_community_row.ui";
+
 inline constexpr auto presets_menu_ui = "/com/github/wwmm/easyeffects/ui/presets_menu.ui";
 
 inline constexpr auto reverb_ui = "/com/github/wwmm/easyeffects/ui/reverb.ui";
