@@ -61,9 +61,9 @@ auto missing_plugin_box(const std::string& base_name, const std::string& package
 
 void show_simple_message_dialog(GtkWidget* parent, const std::string& title, const std::string& descr);
 
-auto parse_spinbutton_output(GtkSpinButton* button, const char* unit, const bool& lower_bound = true) -> bool;
+auto parse_spinbutton_output(GtkSpinButton* button, const char* unit, const bool& lower_bound = true) -> gboolean;
 
-auto parse_spinbutton_input(GtkSpinButton* button, double* new_value, const bool& lower_bound = true) -> int;
+auto parse_spinbutton_input(GtkSpinButton* button, gdouble* new_value, const bool& lower_bound = true) -> gint;
 
 auto get_new_filter_serial() -> uint;
 
@@ -213,7 +213,9 @@ void gsettings_bind_enum_to_combo_widget(GSettings* settings,
 
         g_settings_set_enum(d->settings, d->key, static_cast<gint>(g_value_get_uint(value)));
 
-        return g_variant_new_string(g_settings_get_string(d->settings, d->key));
+        const auto str_value = util::gsettings_get_string(d->settings, d->key);
+
+        return g_variant_new_string(str_value.c_str());
       },
       new Data({.settings = settings, .key = key}),
       +[](gpointer user_data) {
