@@ -1,5 +1,5 @@
 /*
- *  Copyright © 2017-2023 Wellington Wallace
+ *  Copyright © 2017-2024 Wellington Wallace
  *
  *  This file is part of Easy Effects.
  *
@@ -18,6 +18,32 @@
  */
 
 #include "blocklist_menu.hpp"
+#include <gio/gio.h>
+#include <glib-object.h>
+#include <glib.h>
+#include <gobject/gobject.h>
+#include <gtk/gtk.h>
+#include <gtk/gtkbutton.h>
+#include <gtk/gtkcheckbutton.h>
+#include <gtk/gtklabel.h>
+#include <gtk/gtklistitem.h>
+#include <gtk/gtklistview.h>
+#include <gtk/gtkpopover.h>
+#include <gtk/gtkscrolledwindow.h>
+#include <gtk/gtkshortcut.h>
+#include <gtk/gtksignallistitemfactory.h>
+#include <gtk/gtkstringlist.h>
+#include <gtk/gtktext.h>
+#include <pango/pango-layout.h>
+#include <sigc++/connection.h>
+#include <algorithm>
+#include <vector>
+#include "application.hpp"
+#include "pipeline_type.hpp"
+#include "tags_app.hpp"
+#include "tags_resources.hpp"
+#include "tags_schema.hpp"
+#include "util.hpp"
 
 namespace ui::blocklist_menu {
 
