@@ -37,6 +37,7 @@
 #include "plugin_base.hpp"
 #include "resampler.hpp"
 #include "tags_plugin_name.hpp"
+#include "tags_resources.hpp"
 #include "util.hpp"
 
 namespace {
@@ -50,10 +51,34 @@ constexpr auto CONVPROC_SCHEDULER_CLASS = SCHED_FIFO;
 Convolver::Convolver(const std::string& tag,
                      const std::string& schema,
                      const std::string& schema_path,
-                     PipeManager* pipe_manager)
-    : PluginBase(tag, tags::plugin_name::convolver, tags::plugin_package::zita, schema, schema_path, pipe_manager),
+                     PipeManager* pipe_manager,
+                     PipelineType pipe_type)
+    : PluginBase(tag,
+                 tags::plugin_name::convolver,
+                 tags::plugin_package::zita,
+                 schema,
+                 schema_path,
+                 pipe_manager,
+                 pipe_type),
       do_autogain(g_settings_get_boolean(settings, "autogain") != 0),
       ir_width(g_settings_get_int(settings, "ir-width")) {
+  // Initialize directories for local and community irs
+  local_dir_irs = std::string{g_get_user_config_dir()} + "/easyeffects/irs";
+
+  // Flatpak specific path (.flatpak-info always present for apps running in the flatpak sandbox)
+  if (std::filesystem::is_regular_file(tags::resources::flatpak_info_file)) {
+    system_data_dir_irs.push_back("/app/extensions/Presets/irs");
+  }
+
+  // Regular paths
+  for (const gchar* const* xdg_data_dirs = g_get_system_data_dirs(); *xdg_data_dirs != nullptr;) {
+    std::string dir = *xdg_data_dirs++;
+
+    dir += dir.ends_with("/") ? "" : "/";
+
+    system_data_dir_irs.push_back(dir + "easyeffects/irs");
+  }
+
   gconnections.push_back(g_signal_connect(settings, "changed::ir-width",
                                           G_CALLBACK(+[](GSettings* settings, char* key, gpointer user_data) {
                                             auto* self = static_cast<Convolver*>(user_data);
@@ -72,7 +97,7 @@ Convolver::Convolver(const std::string& tag,
                                           }),
                                           this));
 
-  gconnections.push_back(g_signal_connect(settings, "changed::kernel-path",
+  gconnections.push_back(g_signal_connect(settings, "changed::kernel-name",
                                           G_CALLBACK(+[](GSettings* settings, char* key, gpointer user_data) {
                                             auto* self = static_cast<Convolver*>(user_data);
 
@@ -277,17 +302,59 @@ void Convolver::process(std::span<float>& left_in,
   }
 }
 
+auto Convolver::search_irs_path(const std::string& name) -> std::string {
+  // Given the irs name without extension, search the full path on the filesystem.
+  const auto irs_filename = name + irs_ext;
+
+  const auto* lcp_key = (pipeline_type == PipelineType::input) ? "last-loaded-input-community-package"
+                                                               : "last-loaded-output-community-package";
+
+  const auto community_package = util::gsettings_get_string(global_settings, lcp_key);
+
+  std::string irs_full_path;
+
+  if (community_package.empty()) {
+    // Search local irs file.
+    const auto local_irs_file = std::filesystem::path{local_dir_irs + "/" + irs_filename};
+
+    if (std::filesystem::exists(local_irs_file)) {
+      irs_full_path = local_irs_file.c_str();
+    }
+  } else {
+    // Search irs file in community package paths.
+    for (const auto& xdg_irs_dir : system_data_dir_irs) {
+      if (util::search_filename(std::filesystem::path{xdg_irs_dir + "/" + community_package}, irs_filename,
+                                irs_full_path, 3U)) {
+        break;
+      }
+    }
+  }
+
+  return irs_full_path;
+}
+
 void Convolver::read_kernel_file() {
   kernel_is_initialized = false;
 
-  const auto path = util::gsettings_get_string(settings, "kernel-path");
+  const auto name = util::gsettings_get_string(settings, "kernel-name");
 
-  if (path.empty()) {
-    util::warning(log_tag + name + ": irs file path is null. Entering passthrough mode...");
+  if (name.empty()) {
+    util::warning(log_tag + name + ": irs filename is null. Entering passthrough mode...");
 
     return;
   }
 
+  const auto path = search_irs_path(name);
+
+  // If the search fails, the path is empty
+  if (path.empty()) {
+    util::warning(log_tag + name + ": irs filename does not exist. Entering passthrough mode...");
+
+    return;
+  }
+
+  util::debug("trying to load irs: " + path);
+
   // SndfileHandle might have issues with std::string, so we provide cstring
 
   SndfileHandle file = SndfileHandle(path.c_str());
@@ -341,7 +408,7 @@ void Convolver::read_kernel_file() {
 
   kernel_is_initialized = true;
 
-  util::debug(log_tag + name + ": kernel initialized");
+  util::debug(log_tag + name + ": kernel correctly initialized");
 }
 
 void Convolver::apply_kernel_autogain() {
