@@ -65,6 +65,8 @@ struct _ConvolverMenuImpulses {
 
   GSettings *settings, *app_settings;
 
+  std::shared_ptr<Convolver> convolver;
+
   app::Application* application;
 };
 
@@ -151,7 +153,7 @@ void on_import_irs_clicked(ConvolverMenuImpulses* self, GtkButton* btn) {
   gtk_file_dialog_set_title(dialog, _("Import Impulse File"));
   gtk_file_dialog_set_accept_label(dialog, _("Open"));
 
-  auto* init_folder = g_file_new_for_path(SYSTEM_IRS_DIR);
+  auto* init_folder = g_file_new_for_path(g_get_home_dir());
 
   gtk_file_dialog_set_initial_folder(dialog, init_folder);
 
@@ -162,7 +164,7 @@ void on_import_irs_clicked(ConvolverMenuImpulses* self, GtkButton* btn) {
   auto* filter = gtk_file_filter_new();
 
   gtk_file_filter_set_name(filter, _("Impulse Response"));
-  gtk_file_filter_add_pattern(filter, "*.irs");
+  gtk_file_filter_add_pattern(filter, ("*"s + irs_ext).c_str());
   gtk_file_filter_add_pattern(filter, "*.wav");
 
   g_list_store_append(filters, filter);
@@ -238,17 +240,23 @@ void setup_listview(ConvolverMenuImpulses* self) {
                      g_object_set_data(G_OBJECT(item), "remove", remove);
 
                      g_signal_connect(load, "clicked", G_CALLBACK(+[](GtkButton* btn, ConvolverMenuImpulses* self) {
-                                        if (auto* string_object =
-                                                GTK_STRING_OBJECT(g_object_get_data(G_OBJECT(btn), "string-object"));
-                                            string_object != nullptr) {
-                                          auto* name = gtk_string_object_get_string(string_object);
+                                        auto* string_object =
+                                            GTK_STRING_OBJECT(g_object_get_data(G_OBJECT(btn), "string-object"));
 
-                                          auto irs_file = irs_dir / std::filesystem::path{name};
-
-                                          irs_file += irs_ext;
-
-                                          g_settings_set_string(self->settings, "kernel-path", irs_file.c_str());
+                                        if (string_object == nullptr) {
+                                          return;
                                         }
+
+                                        const auto* lcp_key = (self->convolver->pipeline_type == PipelineType::input)
+                                                                  ? "last-loaded-input-community-package"
+                                                                  : "last-loaded-output-community-package";
+
+                                        // irs loaded from the convolver menu are always local.
+                                        g_settings_reset(self->app_settings, lcp_key);
+
+                                        auto* name = gtk_string_object_get_string(string_object);
+
+                                        g_settings_set_string(self->settings, "kernel-name", name);
                                       }),
                                       self);
 
@@ -322,9 +330,14 @@ void setup_listview(ConvolverMenuImpulses* self) {
   g_object_unref(selection);
 }
 
-void setup(ConvolverMenuImpulses* self, const std::string& schema_path, app::Application* application) {
+void setup(ConvolverMenuImpulses* self,
+           const std::string& schema_path,
+           app::Application* application,
+           std::shared_ptr<Convolver> convolver) {
   self->application = application;
 
+  self->convolver = convolver;
+
   self->settings = g_settings_new_with_path(tags::schema::convolver::id, schema_path.c_str());
 
   setup_listview(self);
