@@ -1,5 +1,5 @@
 /*
- *  Copyright © 2017-2023 Wellington Wallace
+ *  Copyright © 2017-2024 Wellington Wallace
  *
  *  This file is part of Easy Effects.
  *
@@ -18,6 +18,13 @@
  */
 
 #include "convolver_ui_common.hpp"
+#include <cstddef>
+#include <filesystem>
+#include <sndfile.hh>
+#include <string>
+#include <tuple>
+#include <vector>
+#include "util.hpp"
 
 namespace ui::convolver {
 
