@@ -32,8 +32,15 @@
 Delay::Delay(const std::string& tag,
              const std::string& schema,
              const std::string& schema_path,
-             PipeManager* pipe_manager)
-    : PluginBase(tag, tags::plugin_name::delay, tags::plugin_package::lsp, schema, schema_path, pipe_manager) {
+             PipeManager* pipe_manager,
+             PipelineType pipe_type)
+    : PluginBase(tag,
+                 tags::plugin_name::delay,
+                 tags::plugin_package::lsp,
+                 schema,
+                 schema_path,
+                 pipe_manager,
+                 pipe_type) {
   lv2_wrapper = std::make_unique<lv2::Lv2Wrapper>("http://lsp-plug.in/plugins/lv2/comp_delay_x2_stereo");
 
   package_installed = lv2_wrapper->found_plugin;
