@@ -1,5 +1,5 @@
 /*
- *  Copyright © 2017-2023 Wellington Wallace
+ *  Copyright © 2017-2024 Wellington Wallace
  *
  *  This file is part of Easy Effects.
  *
@@ -17,9 +17,20 @@
  *  along with Easy Effects. If not, see <https://www.gnu.org/licenses/>.
  */
 
+#include <gio/gio.h>
+#include <glib-object.h>
 #include <glib-unix.h>
+#include <glib.h>
+#include <libintl.h>
+#include <cerrno>
+#include <cstdlib>
+#include <exception>
+#include <iostream>
+#include <ostream>
+#include <string>
 #include "application.hpp"
 #include "config.h"
+#include "util.hpp"
 
 auto sigterm(void* data) -> int {
   auto* app = G_APPLICATION(data);
@@ -61,7 +72,7 @@ auto main(int argc, char* argv[]) -> int {
 
     return status;
   } catch (const std::exception& e) {
-    std::cerr << e.what() << std::endl;
+    std::cerr << e.what() << '\n';
 
     return EXIT_FAILURE;
   }
