@@ -294,6 +294,58 @@ void on_listen_mic_toggled(EffectsBox* self, GtkToggleButton* button) {
   self->data->application->sie->set_listen_to_mic(gtk_toggle_button_get_active(button) != 0);
 }
 
+static gboolean
+spectrum_data_update(GtkWidget* widget, GdkFrameClock* frame_clock, EffectsBox* self) {
+  if (!ui::chart::get_is_visible(self->spectrum_chart)) {
+    return G_SOURCE_CONTINUE;
+  }
+
+  if (!schedule_signal_idle) {
+    return G_SOURCE_CONTINUE;
+  }
+
+  auto [rate, n_bands, magnitudes] = self->data->effects_base->spectrum->compute_magnitudes();
+
+  // No new data available, no redraw required.
+  if (rate == 0 || n_bands == 0) {
+    return G_SOURCE_CONTINUE;
+  }
+
+  if (self->data->spectrum_rate != rate || self->data->spectrum_n_bands != n_bands) {
+    self->data->spectrum_rate = rate;
+    self->data->spectrum_n_bands = n_bands;
+
+    init_spectrum_frequency_axis(self);
+  }
+
+  auto* acc = gsl_interp_accel_alloc();
+  auto* spline = gsl_spline_alloc(gsl_interp_steffen, n_bands);
+
+  gsl_spline_init(spline, self->data->spectrum_freqs.data(), magnitudes, n_bands);
+
+  for (size_t n = 0; n < self->data->spectrum_x_axis.size(); n++) {
+    self->data->spectrum_mag[n] =
+        static_cast<float>(gsl_spline_eval(spline, self->data->spectrum_x_axis[n], acc));
+  }
+
+  gsl_spline_free(spline);
+  gsl_interp_accel_free(acc);
+
+  std::ranges::for_each(self->data->spectrum_mag, [](auto& v) {
+    v = 10.0F * std::log10(v);
+
+    if (!std::isinf(v)) {
+      v = (v > util::minimum_db_level) ? v : util::minimum_db_level;
+    } else {
+      v = util::minimum_db_level;
+    }
+  });
+
+  ui::chart::set_y_data(self->spectrum_chart, self->data->spectrum_mag);
+
+  return G_SOURCE_CONTINUE;
+}
+
 void setup(EffectsBox* self, app::Application* application, PipelineType pipeline_type, GtkIconTheme* icon_theme) {
   self->data->application = application;
   self->data->pipeline_type = pipeline_type;
@@ -395,52 +447,8 @@ void setup(EffectsBox* self, app::Application* application, PipelineType pipelin
 
   // spectrum array
 
-  self->data->connections.push_back(
-      self->data->effects_base->spectrum->power.connect([=](uint rate, uint n_bands, std::vector<double> magnitudes) {
-        if (self == nullptr) {
-          return;
-        }
-
-        if (!ui::chart::get_is_visible(self->spectrum_chart)) {
-          return;
-        }
-
-        if (!schedule_signal_idle) {
-          return;
-        }
-
-        if (self->data->spectrum_rate != rate || self->data->spectrum_n_bands != n_bands) {
-          self->data->spectrum_rate = rate;
-          self->data->spectrum_n_bands = n_bands;
-
-          init_spectrum_frequency_axis(self);
-        }
-
-        auto* acc = gsl_interp_accel_alloc();
-        auto* spline = gsl_spline_alloc(gsl_interp_steffen, n_bands);
-
-        gsl_spline_init(spline, self->data->spectrum_freqs.data(), magnitudes.data(), n_bands);
-
-        for (size_t n = 0; n < self->data->spectrum_x_axis.size(); n++) {
-          self->data->spectrum_mag[n] =
-              static_cast<float>(gsl_spline_eval(spline, self->data->spectrum_x_axis[n], acc));
-        }
-
-        gsl_spline_free(spline);
-        gsl_interp_accel_free(acc);
-
-        std::ranges::for_each(self->data->spectrum_mag, [](auto& v) {
-          v = 10.0F * std::log10(v);
-
-          if (!std::isinf(v)) {
-            v = (v > util::minimum_db_level) ? v : util::minimum_db_level;
-          } else {
-            v = util::minimum_db_level;
-          }
-        });
-
-        ui::chart::set_y_data(self->spectrum_chart, self->data->spectrum_mag);
-      }));
+  gtk_widget_add_tick_callback(GTK_WIDGET(self->spectrum_chart), (GtkTickCallback)spectrum_data_update,
+                               self, NULL);
 
   // As we are showing the window we want the filters to send notifications about level meters, etc
 
