@@ -31,8 +31,15 @@
 Exciter::Exciter(const std::string& tag,
                  const std::string& schema,
                  const std::string& schema_path,
-                 PipeManager* pipe_manager)
-    : PluginBase(tag, tags::plugin_name::exciter, tags::plugin_package::calf, schema, schema_path, pipe_manager) {
+                 PipeManager* pipe_manager,
+                 PipelineType pipe_type)
+    : PluginBase(tag,
+                 tags::plugin_name::exciter,
+                 tags::plugin_package::calf,
+                 schema,
+                 schema_path,
+                 pipe_manager,
+                 pipe_type) {
   lv2_wrapper = std::make_unique<lv2::Lv2Wrapper>("http://calf.sourceforge.net/plugins/Exciter");
 
   package_installed = lv2_wrapper->found_plugin;
