@@ -1,5 +1,5 @@
 /*
- *  Copyright © 2017-2023 Wellington Wallace
+ *  Copyright © 2017-2024 Wellington Wallace
  *
  *  This file is part of Easy Effects.
  *
@@ -18,6 +18,10 @@
  */
 
 #include "fir_filter_highpass.hpp"
+#include <algorithm>
+#include <string>
+#include <utility>
+#include "fir_filter_base.hpp"
 
 FirFilterHighpass::FirFilterHighpass(std::string tag) : FirFilterBase(std::move(tag)) {}
 
