@@ -1,5 +1,5 @@
 /*
- *  Copyright © 2017-2023 Wellington Wallace
+ *  Copyright © 2017-2024 Wellington Wallace
  *
  *  This file is part of Easy Effects.
  *
@@ -18,6 +18,32 @@
  */
 
 #include "gate_ui.hpp"
+#include <STTypes.h>
+#define FMT_HEADER_ONLY
+#include <fmt/core.h>
+#include <fmt/format.h>
+#include <gio/gio.h>
+#include <gio/gliststore.h>
+#include <glib-object.h>
+#include <glib.h>
+#include <glibconfig.h>
+#include <gobject/gobject.h>
+#include <gtk/gtk.h>
+#include <gtk/gtkdropdown.h>
+#include <gtk/gtksingleselection.h>
+#include <sigc++/connection.h>
+#include <memory>
+#include <string>
+#include <vector>
+#include "gate.hpp"
+#include "node_info_holder.hpp"
+#include "pipe_manager.hpp"
+#include "pipe_objects.hpp"
+#include "tags_pipewire.hpp"
+#include "tags_resources.hpp"
+#include "tags_schema.hpp"
+#include "ui_helpers.hpp"
+#include "util.hpp"
 
 namespace ui::gate_box {
 
@@ -137,141 +163,181 @@ void setup(GateBox* self, std::shared_ptr<Gate> gate, const std::string& schema_
   }
 
   self->data->connections.push_back(gate->input_level.connect([=](const float left, const float right) {
-    util::idle_add([=]() {
-      if (get_ignore_filter_idle_add(serial)) {
-        return;
-      }
+    g_object_ref(self);
 
-      update_level(self->input_level_left, self->input_level_left_label, self->input_level_right,
-                   self->input_level_right_label, left, right);
-    });
+    util::idle_add(
+        [=]() {
+          if (get_ignore_filter_idle_add(serial)) {
+            return;
+          }
+
+          update_level(self->input_level_left, self->input_level_left_label, self->input_level_right,
+                       self->input_level_right_label, left, right);
+        },
+        [=]() { g_object_unref(self); });
   }));
 
   self->data->connections.push_back(gate->output_level.connect([=](const float left, const float right) {
-    util::idle_add([=]() {
-      if (get_ignore_filter_idle_add(serial)) {
-        return;
-      }
+    g_object_ref(self);
 
-      update_level(self->output_level_left, self->output_level_left_label, self->output_level_right,
-                   self->output_level_right_label, left, right);
-    });
+    util::idle_add(
+        [=]() {
+          if (get_ignore_filter_idle_add(serial)) {
+            return;
+          }
+
+          update_level(self->output_level_left, self->output_level_left_label, self->output_level_right,
+                       self->output_level_right_label, left, right);
+        },
+        [=]() { g_object_unref(self); });
   }));
 
   self->data->connections.push_back(gate->attack_zone_start.connect([=](const float value) {
-    util::idle_add([=]() {
-      if (get_ignore_filter_idle_add(serial)) {
-        return;
-      }
+    g_object_ref(self);
 
-      if (!GTK_IS_LABEL(self->attack_zone_start_label)) {
-        return;
-      }
+    util::idle_add(
+        [=]() {
+          if (get_ignore_filter_idle_add(serial)) {
+            return;
+          }
 
-      gtk_label_set_text(self->attack_zone_start_label,
-                         fmt::format(ui::get_user_locale(), "{0:.1Lf}", util::linear_to_db(value)).c_str());
-    });
+          if (!GTK_IS_LABEL(self->attack_zone_start_label)) {
+            return;
+          }
+
+          gtk_label_set_text(self->attack_zone_start_label,
+                             fmt::format(ui::get_user_locale(), "{0:.1Lf}", util::linear_to_db(value)).c_str());
+        },
+        [=]() { g_object_unref(self); });
   }));
 
   self->data->connections.push_back(gate->attack_threshold.connect([=](const float value) {
-    util::idle_add([=]() {
-      if (get_ignore_filter_idle_add(serial)) {
-        return;
-      }
+    g_object_ref(self);
 
-      if (!GTK_IS_LABEL(self->attack_threshold_label)) {
-        return;
-      }
+    util::idle_add(
+        [=]() {
+          if (get_ignore_filter_idle_add(serial)) {
+            return;
+          }
 
-      gtk_label_set_text(self->attack_threshold_label,
-                         fmt::format(ui::get_user_locale(), "{0:.1Lf}", util::linear_to_db(value)).c_str());
-    });
+          if (!GTK_IS_LABEL(self->attack_threshold_label)) {
+            return;
+          }
+
+          gtk_label_set_text(self->attack_threshold_label,
+                             fmt::format(ui::get_user_locale(), "{0:.1Lf}", util::linear_to_db(value)).c_str());
+        },
+        [=]() { g_object_unref(self); });
   }));
 
   self->data->connections.push_back(gate->release_zone_start.connect([=](const float value) {
-    util::idle_add([=]() {
-      if (get_ignore_filter_idle_add(serial)) {
-        return;
-      }
+    g_object_ref(self);
 
-      if (!GTK_IS_LABEL(self->release_zone_start_label)) {
-        return;
-      }
+    util::idle_add(
+        [=]() {
+          if (get_ignore_filter_idle_add(serial)) {
+            return;
+          }
 
-      gtk_label_set_text(self->release_zone_start_label,
-                         fmt::format(ui::get_user_locale(), "{0:.1Lf}", util::linear_to_db(value)).c_str());
-    });
+          if (!GTK_IS_LABEL(self->release_zone_start_label)) {
+            return;
+          }
+
+          gtk_label_set_text(self->release_zone_start_label,
+                             fmt::format(ui::get_user_locale(), "{0:.1Lf}", util::linear_to_db(value)).c_str());
+        },
+        [=]() { g_object_unref(self); });
   }));
 
   self->data->connections.push_back(gate->release_threshold.connect([=](const float value) {
-    util::idle_add([=]() {
-      if (get_ignore_filter_idle_add(serial)) {
-        return;
-      }
+    g_object_ref(self);
 
-      if (!GTK_IS_LABEL(self->release_threshold_label)) {
-        return;
-      }
+    util::idle_add(
+        [=]() {
+          if (get_ignore_filter_idle_add(serial)) {
+            return;
+          }
 
-      gtk_label_set_text(self->release_threshold_label,
-                         fmt::format(ui::get_user_locale(), "{0:.1Lf}", util::linear_to_db(value)).c_str());
-    });
+          if (!GTK_IS_LABEL(self->release_threshold_label)) {
+            return;
+          }
+
+          gtk_label_set_text(self->release_threshold_label,
+                             fmt::format(ui::get_user_locale(), "{0:.1Lf}", util::linear_to_db(value)).c_str());
+        },
+        [=]() { g_object_unref(self); });
   }));
 
   self->data->connections.push_back(gate->reduction.connect([=](const float value) {
-    util::idle_add([=]() {
-      if (get_ignore_filter_idle_add(serial)) {
-        return;
-      }
+    g_object_ref(self);
 
-      if (!GTK_IS_LABEL(self->gain_label)) {
-        return;
-      }
+    util::idle_add(
+        [=]() {
+          if (get_ignore_filter_idle_add(serial)) {
+            return;
+          }
 
-      gtk_label_set_text(self->gain_label, fmt::format("{0:.0Lf}", util::linear_to_db(value)).c_str());
-    });
+          if (!GTK_IS_LABEL(self->gain_label)) {
+            return;
+          }
+
+          gtk_label_set_text(self->gain_label, fmt::format("{0:.0Lf}", util::linear_to_db(value)).c_str());
+        },
+        [=]() { g_object_unref(self); });
   }));
 
   self->data->connections.push_back(gate->envelope.connect([=](const float value) {
-    util::idle_add([=]() {
-      if (get_ignore_filter_idle_add(serial)) {
-        return;
-      }
+    g_object_ref(self);
 
-      if (!GTK_IS_LABEL(self->envelope_label)) {
-        return;
-      }
+    util::idle_add(
+        [=]() {
+          if (get_ignore_filter_idle_add(serial)) {
+            return;
+          }
 
-      gtk_label_set_text(self->envelope_label, fmt::format("{0:.0f}", util::linear_to_db(value)).c_str());
-    });
+          if (!GTK_IS_LABEL(self->envelope_label)) {
+            return;
+          }
+
+          gtk_label_set_text(self->envelope_label, fmt::format("{0:.0f}", util::linear_to_db(value)).c_str());
+        },
+        [=]() { g_object_unref(self); });
   }));
 
   self->data->connections.push_back(gate->sidechain.connect([=](const float value) {
-    util::idle_add([=]() {
-      if (get_ignore_filter_idle_add(serial)) {
-        return;
-      }
+    g_object_ref(self);
 
-      if (!GTK_IS_LABEL(self->sidechain_label)) {
-        return;
-      }
+    util::idle_add(
+        [=]() {
+          if (get_ignore_filter_idle_add(serial)) {
+            return;
+          }
 
-      gtk_label_set_text(self->sidechain_label, fmt::format("{0:.0f}", util::linear_to_db(value)).c_str());
-    });
+          if (!GTK_IS_LABEL(self->sidechain_label)) {
+            return;
+          }
+
+          gtk_label_set_text(self->sidechain_label, fmt::format("{0:.0f}", util::linear_to_db(value)).c_str());
+        },
+        [=]() { g_object_unref(self); });
   }));
 
   self->data->connections.push_back(gate->curve.connect([=](const float value) {
-    util::idle_add([=]() {
-      if (get_ignore_filter_idle_add(serial)) {
-        return;
-      }
+    g_object_ref(self);
 
-      if (!GTK_IS_LABEL(self->curve_label)) {
-        return;
-      }
+    util::idle_add(
+        [=]() {
+          if (get_ignore_filter_idle_add(serial)) {
+            return;
+          }
 
-      gtk_label_set_text(self->curve_label, fmt::format("{0:.0f}", util::linear_to_db(value)).c_str());
-    });
+          if (!GTK_IS_LABEL(self->curve_label)) {
+            return;
+          }
+
+          gtk_label_set_text(self->curve_label, fmt::format("{0:.0f}", util::linear_to_db(value)).c_str());
+        },
+        [=]() { g_object_unref(self); });
   }));
 
   self->data->connections.push_back(pm->source_added.connect([=](const NodeInfo info) {
@@ -391,8 +457,6 @@ void setup(GateBox* self, std::shared_ptr<Gate> gate, const std::string& schema_
 void dispose(GObject* object) {
   auto* self = EE_GATE_BOX(object);
 
-  self->data->gate->set_post_messages(false);
-
   self->data->gate->close_native_ui();
 
   set_ignore_filter_idle_add(self->data->serial, true);
