@@ -32,8 +32,15 @@
 Maximizer::Maximizer(const std::string& tag,
                      const std::string& schema,
                      const std::string& schema_path,
-                     PipeManager* pipe_manager)
-    : PluginBase(tag, tags::plugin_name::maximizer, tags::plugin_package::zam, schema, schema_path, pipe_manager) {
+                     PipeManager* pipe_manager,
+                     PipelineType pipe_type)
+    : PluginBase(tag,
+                 tags::plugin_name::maximizer,
+                 tags::plugin_package::zam,
+                 schema,
+                 schema_path,
+                 pipe_manager,
+                 pipe_type) {
   lv2_wrapper = std::make_unique<lv2::Lv2Wrapper>("urn:zamaudio:ZaMaximX2");
 
   package_installed = lv2_wrapper->found_plugin;
@@ -44,8 +51,6 @@ Maximizer::Maximizer(const std::string& tag,
 
   lv2_wrapper->bind_key_double<"thresh", "threshold">(settings);
 
-  lv2_wrapper->bind_key_double<"ceil", "ceiling">(settings);
-
   lv2_wrapper->bind_key_double<"rel", "release">(settings);
 
   setup_input_output_gain();
