@@ -1,5 +1,5 @@
 /*
- *  Copyright © 2017-2023 Wellington Wallace
+ *  Copyright © 2017-2024 Wellington Wallace
  *
  *  This file is part of Easy Effects.
  *
@@ -18,6 +18,33 @@
  */
 
 #include "multiband_gate_ui.hpp"
+#include <STTypes.h>
+#include <gio/gio.h>
+#include <gio/gliststore.h>
+#include <glib-object.h>
+#include <glib.h>
+#include <glibconfig.h>
+#include <gobject/gobject.h>
+#include <gtk/gtk.h>
+#include <gtk/gtkdropdown.h>
+#include <gtk/gtksingleselection.h>
+#include <sigc++/connection.h>
+#include <array>
+#include <cstddef>
+#include <memory>
+#include <string>
+#include <vector>
+#include "multiband_gate.hpp"
+#include "multiband_gate_band_box.hpp"
+#include "node_info_holder.hpp"
+#include "pipe_manager.hpp"
+#include "pipe_objects.hpp"
+#include "tags_multiband_gate.hpp"
+#include "tags_pipewire.hpp"
+#include "tags_resources.hpp"
+#include "tags_schema.hpp"
+#include "ui_helpers.hpp"
+#include "util.hpp"
 
 namespace ui::multiband_gate_box {
 
@@ -181,77 +208,101 @@ void setup(MultibandGateBox* self,
   }
 
   self->data->connections.push_back(multiband_gate->input_level.connect([=](const float left, const float right) {
-    util::idle_add([=]() {
-      if (get_ignore_filter_idle_add(serial)) {
-        return;
-      }
+    g_object_ref(self);
 
-      update_level(self->input_level_left, self->input_level_left_label, self->input_level_right,
-                   self->input_level_right_label, left, right);
-    });
+    util::idle_add(
+        [=]() {
+          if (get_ignore_filter_idle_add(serial)) {
+            return;
+          }
+
+          update_level(self->input_level_left, self->input_level_left_label, self->input_level_right,
+                       self->input_level_right_label, left, right);
+        },
+        [=]() { g_object_unref(self); });
   }));
 
   self->data->connections.push_back(multiband_gate->output_level.connect([=](const float left, const float right) {
-    util::idle_add([=]() {
-      if (get_ignore_filter_idle_add(serial)) {
-        return;
-      }
+    g_object_ref(self);
 
-      update_level(self->output_level_left, self->output_level_left_label, self->output_level_right,
-                   self->output_level_right_label, left, right);
-    });
+    util::idle_add(
+        [=]() {
+          if (get_ignore_filter_idle_add(serial)) {
+            return;
+          }
+
+          update_level(self->output_level_left, self->output_level_left_label, self->output_level_right,
+                       self->output_level_right_label, left, right);
+        },
+        [=]() { g_object_unref(self); });
   }));
 
   self->data->connections.push_back(
       multiband_gate->frequency_range.connect([=](const std::array<float, tags::multiband_gate::n_bands> values) {
-        util::idle_add([=]() {
-          if (get_ignore_filter_idle_add(serial)) {
-            return;
-          }
+        g_object_ref(self);
 
-          for (size_t n = 0U; n < values.size(); n++) {
-            ui::multiband_gate_band_box::set_end_label(self->bands[n], values[n]);
-          }
-        });
+        util::idle_add(
+            [=]() {
+              if (get_ignore_filter_idle_add(serial)) {
+                return;
+              }
+
+              for (size_t n = 0U; n < values.size(); n++) {
+                ui::multiband_gate_band_box::set_end_label(self->bands[n], values[n]);
+              }
+            },
+            [=]() { g_object_unref(self); });
       }));
 
   self->data->connections.push_back(
       multiband_gate->envelope.connect([=](const std::array<float, tags::multiband_gate::n_bands> values) {
-        util::idle_add([=]() {
-          if (get_ignore_filter_idle_add(serial)) {
-            return;
-          }
+        g_object_ref(self);
 
-          for (size_t n = 0U; n < values.size(); n++) {
-            ui::multiband_gate_band_box::set_envelope_label(self->bands[n], values[n]);
-          }
-        });
+        util::idle_add(
+            [=]() {
+              if (get_ignore_filter_idle_add(serial)) {
+                return;
+              }
+
+              for (size_t n = 0U; n < values.size(); n++) {
+                ui::multiband_gate_band_box::set_envelope_label(self->bands[n], values[n]);
+              }
+            },
+            [=]() { g_object_unref(self); });
       }));
 
   self->data->connections.push_back(
       multiband_gate->curve.connect([=](const std::array<float, tags::multiband_gate::n_bands> values) {
-        util::idle_add([=]() {
-          if (get_ignore_filter_idle_add(serial)) {
-            return;
-          }
+        g_object_ref(self);
 
-          for (size_t n = 0U; n < values.size(); n++) {
-            ui::multiband_gate_band_box::set_curve_label(self->bands[n], values[n]);
-          }
-        });
+        util::idle_add(
+            [=]() {
+              if (get_ignore_filter_idle_add(serial)) {
+                return;
+              }
+
+              for (size_t n = 0U; n < values.size(); n++) {
+                ui::multiband_gate_band_box::set_curve_label(self->bands[n], values[n]);
+              }
+            },
+            [=]() { g_object_unref(self); });
       }));
 
   self->data->connections.push_back(
       multiband_gate->reduction.connect([=](const std::array<float, tags::multiband_gate::n_bands> values) {
-        util::idle_add([=]() {
-          if (get_ignore_filter_idle_add(serial)) {
-            return;
-          }
+        g_object_ref(self);
 
-          for (size_t n = 0U; n < values.size(); n++) {
-            ui::multiband_gate_band_box::set_gain_label(self->bands[n], values[n]);
-          }
-        });
+        util::idle_add(
+            [=]() {
+              if (get_ignore_filter_idle_add(serial)) {
+                return;
+              }
+
+              for (size_t n = 0U; n < values.size(); n++) {
+                ui::multiband_gate_band_box::set_gain_label(self->bands[n], values[n]);
+              }
+            },
+            [=]() { g_object_unref(self); });
       }));
 
   self->data->connections.push_back(pm->source_added.connect([=](const NodeInfo info) {
@@ -322,8 +373,6 @@ void setup(MultibandGateBox* self,
 void dispose(GObject* object) {
   auto* self = EE_MULTIBAND_GATE_BOX(object);
 
-  self->data->multiband_gate->set_post_messages(false);
-
   self->data->multiband_gate->close_native_ui();
 
   set_ignore_filter_idle_add(self->data->serial, true);
