@@ -29,8 +29,9 @@
 OutputLevel::OutputLevel(const std::string& tag,
                          const std::string& schema,
                          const std::string& schema_path,
-                         PipeManager* pipe_manager)
-    : PluginBase(tag, "output_level", tags::plugin_package::ee, schema, schema_path, pipe_manager) {}
+                         PipeManager* pipe_manager,
+                         PipelineType pipe_type)
+    : PluginBase(tag, "output_level", tags::plugin_package::ee, schema, schema_path, pipe_manager, pipe_type) {}
 
 OutputLevel::~OutputLevel() {
   if (connected_to_pw) {
