@@ -130,6 +130,8 @@ struct Data {
 struct _PluginsBox {
   GtkBox parent_instance;
 
+  GtkToggleButton* toggle_plugins_list;
+
   GtkMenuButton* menubutton_plugins;
 
   GtkOverlay* plugin_overlay;
@@ -168,7 +170,7 @@ void add_plugins_to_stack(PluginsBox* self) {
 
   // saving the current visible page name for later usage
 
-  std::string visible_page_name =
+  const std::string visible_page_name =
       (gtk_stack_get_visible_child_name(self->stack) != nullptr) ? gtk_stack_get_visible_child_name(self->stack) : "";
 
   // removing all plugins
@@ -559,6 +561,39 @@ void add_plugins_to_stack(PluginsBox* self) {
   }
 }
 
+void show_adjacent_plugin(PluginsBox* self, const int& increment) {
+  const auto plugins_list = util::gchar_array_to_vector(g_settings_get_strv(self->settings, "plugins"));
+
+  if (plugins_list.empty()) {
+    return;
+  }
+
+  const std::string visible_page_name =
+      (gtk_stack_get_visible_child_name(self->stack) != nullptr) ? gtk_stack_get_visible_child_name(self->stack) : "";
+
+  if (visible_page_name.empty()) {
+    return;
+  }
+
+  auto it = std::ranges::find(plugins_list, visible_page_name);
+
+  if (it == plugins_list.end()) {
+    return;
+  }
+
+  if (auto adj_it = it + increment; adj_it >= plugins_list.begin() && adj_it < plugins_list.end()) {
+    gtk_stack_set_visible_child_name(self->stack, (*adj_it).c_str());
+  }
+}
+
+void on_prev_plugin(PluginsBox* self, GtkButton* button) {
+  show_adjacent_plugin(self, -1);
+}
+
+void on_next_plugin(PluginsBox* self, GtkButton* button) {
+  show_adjacent_plugin(self, 1);
+}
+
 void setup_listview(PluginsBox* self) {
   auto* factory = gtk_signal_list_item_factory_new();
 
@@ -569,13 +604,15 @@ void setup_listview(PluginsBox* self) {
         auto builder = gtk_builder_new_from_resource(tags::resources::plugin_row_ui);
 
         auto* top_box = gtk_builder_get_object(builder, "top_box");
-        auto* plugin_icon = gtk_builder_get_object(builder, "plugin_icon");
+        auto* plugin_enabled_icon = gtk_builder_get_object(builder, "plugin_enabled_icon");
+        auto* plugin_bypassed_icon = gtk_builder_get_object(builder, "plugin_bypassed_icon");
         auto* remove = gtk_builder_get_object(builder, "remove");
         auto* enable = gtk_builder_get_object(builder, "enable");
         auto* drag_handle = gtk_builder_get_object(builder, "drag_handle");
 
         g_object_set_data(G_OBJECT(item), "top_box", top_box);
-        g_object_set_data(G_OBJECT(item), "plugin_icon", plugin_icon);
+        g_object_set_data(G_OBJECT(item), "plugin_enabled_icon", plugin_enabled_icon);
+        g_object_set_data(G_OBJECT(item), "plugin_bypassed_icon", plugin_bypassed_icon);
         g_object_set_data(G_OBJECT(item), "name", gtk_builder_get_object(builder, "name"));
         g_object_set_data(G_OBJECT(item), "remove", remove);
         g_object_set_data(G_OBJECT(item), "enable", enable);
@@ -706,9 +743,6 @@ void setup_listview(PluginsBox* self) {
         auto* label = static_cast<GtkLabel*>(g_object_get_data(G_OBJECT(item), "name"));
         auto* remove = static_cast<GtkButton*>(g_object_get_data(G_OBJECT(item), "remove"));
         auto* enable = static_cast<GtkToggleButton*>(g_object_get_data(G_OBJECT(item), "enable"));
-        auto* plugin_icon = static_cast<GtkImage*>(g_object_get_data(G_OBJECT(item), "plugin_icon"));
-
-        gtk_image_set_from_icon_name(plugin_icon, "ee-arrow-down-symbolic");
 
         auto* child_item = gtk_list_item_get_item(item);
 
@@ -797,6 +831,8 @@ void setup(PluginsBox* self, app::Application* application, PipelineType pipelin
     }
   }
 
+  gsettings_bind_widget(self->settings, "show-plugins-list", self->toggle_plugins_list);
+
   ui::plugins_menu::setup(self->plugins_menu, application, pipeline_type);
 
   setup_listview(self);
@@ -890,6 +926,7 @@ void plugins_box_class_init(PluginsBoxClass* klass) {
 
   gtk_widget_class_set_template_from_resource(widget_class, tags::resources::plugins_box_ui);
 
+  gtk_widget_class_bind_template_child(widget_class, PluginsBox, toggle_plugins_list);
   gtk_widget_class_bind_template_child(widget_class, PluginsBox, menubutton_plugins);
   gtk_widget_class_bind_template_child(widget_class, PluginsBox, plugin_overlay);
   gtk_widget_class_bind_template_child(widget_class, PluginsBox, overlay_no_plugins);
@@ -901,6 +938,9 @@ void plugins_box_class_init(PluginsBoxClass* klass) {
   gtk_widget_class_bind_template_child(widget_class, PluginsBox, endpoint_box);
   gtk_widget_class_bind_template_child(widget_class, PluginsBox, endpoint_icon);
   gtk_widget_class_bind_template_child(widget_class, PluginsBox, endpoint_name);
+
+  gtk_widget_class_bind_template_callback(widget_class, on_prev_plugin);
+  gtk_widget_class_bind_template_callback(widget_class, on_next_plugin);
 }
 
 void plugins_box_init(PluginsBox* self) {
