@@ -26,12 +26,14 @@
 #include <glibconfig.h>
 #include <gobject/gobject.h>
 #include <gtk/gtk.h>
+#include <gtk/gtkexpression.h>
 #include <gtk/gtkshortcut.h>
+#include <gtk/gtkstringfilter.h>
 #include <sigc++/connection.h>
+#include <regex>
 #include <string>
 #include <vector>
 #include "application.hpp"
-#include "config.h"
 #include "preset_type.hpp"
 #include "tags_app.hpp"
 #include "tags_resources.hpp"
@@ -55,15 +57,27 @@ struct Data {
 struct _PresetsMenu {
   GtkPopover parent_instance;
 
-  GtkScrolledWindow* scrolled_window;
+  AdwViewStack* stack;
 
-  GtkListView* listview;
+  GtkScrolledWindow *scrolled_window_local, *scrolled_window_community;
 
-  GtkText* name;
+  GtkBox* community_main_box;
 
-  GtkLabel* last_used_name;
+  GtkListView *listview_local, *listview_community;
 
-  GtkStringList* string_list;
+  AdwStatusPage* status_page_community_list;
+
+  GtkText* new_preset_name;
+
+  GtkLabel *last_loaded_preset_title, *last_loaded_preset_value;
+
+  GtkStringList *presets_list_local, *presets_list_community;
+
+  GtkSearchEntry* search_community;
+
+  GtkStringFilter* filter_string_community;
+
+  GtkButton* refresh_community_list;
 
   GSettings* settings;
 
@@ -73,23 +87,48 @@ struct _PresetsMenu {
 // NOLINTNEXTLINE
 G_DEFINE_TYPE(PresetsMenu, presets_menu, GTK_TYPE_POPOVER)
 
-void create_preset(PresetsMenu* self, GtkButton* button) {
-  auto name = std::string(g_utf8_make_valid(gtk_editable_get_text(GTK_EDITABLE(self->name)), -1));
+auto closure_community_search_filter(PresetsMenu* self, const char* text) -> const char* {
+  const std::string preset_path{text};
 
+  static const auto re_preset_name = std::regex(R"([^/]+$)");
+
+  std::smatch name_match;
+
+  std::regex_search(preset_path.cbegin(), preset_path.cend(), name_match, re_preset_name);
+
+  return (name_match.size() == 1U) ? g_strdup(name_match.str(0).c_str()) : "";
+}
+
+void create_preset(PresetsMenu* self, GtkButton* button) {
+  std::string name = g_utf8_make_valid(gtk_editable_get_text(GTK_EDITABLE(self->new_preset_name)), -1);
+
+  // Reset input field.
+  gtk_editable_set_text(GTK_EDITABLE(self->new_preset_name), "");
+
+  // Remove leading and trailing whitespaces.
+  util::str_trim(name);
+
+  static const auto json_ext_re = std::regex(R"((?:\.+json)+$)", std::regex::icase);
+
+  // Remove the json extension at the end, if present
+  // (it will be added in PresetsManager::add()).
+  if (std::smatch sm; std::regex_search(name, sm, json_ext_re)) {
+    name = std::regex_replace(name, json_ext_re, "");
+  }
+
+  // Check if empty.
   if (name.empty()) {
     return;
   }
 
-  gtk_editable_set_text(GTK_EDITABLE(self->name), "");
-
-  // Truncate if longer than 100 characters
-
-  if (name.size() > 100U) {
-    name.resize(100U);
+  // Truncate if the name is longer than 100 characters.
+  if (const auto max_length = 100U; name.size() > max_length) {
+    name.resize(max_length);
   }
 
+  // Check for illegal characters.
   if (name.find_first_of("\\/") != std::string::npos) {
-    util::debug(" name " + name + " has illegal file name characters. Aborting preset creation!");
+    util::warning(" name " + name + " has illegal file name characters. Aborting preset creation!");
 
     return;
   }
@@ -97,7 +136,7 @@ void create_preset(PresetsMenu* self, GtkButton* button) {
   self->data->application->presets_manager->add(self->data->preset_type, name);
 }
 
-void import_preset(PresetsMenu* self) {
+void import_preset_from_disk(PresetsMenu* self) {
   auto* active_window = gtk_application_get_active_window(GTK_APPLICATION(self->data->application));
 
   auto* dialog = gtk_file_dialog_new();
@@ -105,7 +144,8 @@ void import_preset(PresetsMenu* self) {
   gtk_file_dialog_set_title(dialog, _("Import Preset"));
   gtk_file_dialog_set_accept_label(dialog, _("Open"));
 
-  auto* init_folder = g_file_new_for_path(SYSTEM_PRESETS_DIR);
+  // Open the dialog from the user home folder.
+  auto* init_folder = g_file_new_for_path(g_get_home_dir());
 
   gtk_file_dialog_set_initial_folder(dialog, init_folder);
 
@@ -143,9 +183,9 @@ void import_preset(PresetsMenu* self) {
           auto* path = g_file_get_path(file);
 
           if (self->data->preset_type == PresetType::output) {
-            self->data->application->presets_manager->import(PresetType::output, path);
+            self->data->application->presets_manager->import_from_filesystem(PresetType::output, path);
           } else if (self->data->preset_type == PresetType::input) {
-            self->data->application->presets_manager->import(PresetType::input, path);
+            self->data->application->presets_manager->import_from_filesystem(PresetType::input, path);
           }
 
           g_free(path);
@@ -157,7 +197,146 @@ void import_preset(PresetsMenu* self) {
 }
 
 template <PresetType preset_type>
-void setup_listview(PresetsMenu* self, GtkListView* listview, GtkStringList* string_list) {
+void setup_community_presets_listview(PresetsMenu* self,
+                                      GtkListView* listview_community,
+                                      GtkStringList* presets_list_community) {
+  auto* factory = gtk_signal_list_item_factory_new();
+
+  // setting the factory callbacks
+
+  g_signal_connect(
+      factory, "setup", G_CALLBACK(+[](GtkSignalListItemFactory* factory, GtkListItem* item, PresetsMenu* self) {
+        auto builder = gtk_builder_new_from_resource(tags::resources::preset_row_community_ui);
+
+        auto* top_box = gtk_builder_get_object(builder, "top_box");
+
+        auto* name = gtk_builder_get_object(builder, "name");
+        auto* package = gtk_builder_get_object(builder, "package");
+
+        auto* try_bt = gtk_builder_get_object(builder, "try");
+        auto* import = gtk_builder_get_object(builder, "import");
+
+        g_object_set_data(G_OBJECT(item), "name", name);
+        g_object_set_data(G_OBJECT(item), "package", package);
+        g_object_set_data(G_OBJECT(item), "try", try_bt);
+        g_object_set_data(G_OBJECT(item), "import", import);
+
+        gtk_list_item_set_activatable(item, 0);
+        gtk_list_item_set_child(item, GTK_WIDGET(top_box));
+
+        g_signal_connect(try_bt, "clicked", G_CALLBACK(+[](GtkButton* button, PresetsMenu* self) {
+                           auto* string_object_preset =
+                               GTK_STRING_OBJECT(g_object_get_data(G_OBJECT(button), "string-object-preset"));
+                           auto* label_package =
+                               GTK_LABEL(g_object_get_data(G_OBJECT(button), "gtk-label-package-name"));
+
+                           if (string_object_preset == nullptr || label_package == nullptr) {
+                             return;
+                           }
+
+                           const std::string preset_path = gtk_string_object_get_string(string_object_preset);
+
+                           const std::string preset_package = gtk_label_get_text(label_package);
+
+                           self->data->application->presets_manager->load_community_preset_file(
+                               preset_type, preset_path, preset_package);
+                         }),
+                         self);
+
+        g_signal_connect(import, "clicked", G_CALLBACK(+[](GtkButton* button, PresetsMenu* self) {
+                           auto* string_object_preset =
+                               GTK_STRING_OBJECT(g_object_get_data(G_OBJECT(button), "string-object-preset"));
+                           auto* label_package =
+                               GTK_LABEL(g_object_get_data(G_OBJECT(button), "gtk-label-package-name"));
+
+                           if (string_object_preset == nullptr || label_package == nullptr) {
+                             return;
+                           }
+
+                           // community presets are indexed by full_path using stem filenames,
+                           // so we need to append the json extension.
+                           const std::string preset_path = gtk_string_object_get_string(string_object_preset) +
+                                                           self->data->application->presets_manager->json_ext;
+
+                           const std::string preset_package = gtk_label_get_text(label_package);
+
+                           self->data->application->presets_manager->import_from_community_package(
+                               preset_type, preset_path, preset_package);
+                         }),
+                         self);
+
+        g_object_unref(builder);
+      }),
+      self);
+
+  g_signal_connect(factory, "bind",
+                   G_CALLBACK(+[](GtkSignalListItemFactory* factory, GtkListItem* item, PresetsMenu* self) {
+                     auto* name = static_cast<GtkLabel*>(g_object_get_data(G_OBJECT(item), "name"));
+                     auto* package = static_cast<GtkLabel*>(g_object_get_data(G_OBJECT(item), "package"));
+
+                     auto* try_bt = static_cast<GtkButton*>(g_object_get_data(G_OBJECT(item), "try"));
+                     auto* import = static_cast<GtkButton*>(g_object_get_data(G_OBJECT(item), "import"));
+
+                     // Get the full path of the community preset item.
+                     auto* preset_path = GTK_STRING_OBJECT(gtk_list_item_get_item(item));
+
+                     // Save community preset path in try and import buttons.
+                     g_object_set_data(G_OBJECT(try_bt), "string-object-preset", preset_path);
+                     g_object_set_data(G_OBJECT(import), "string-object-preset", preset_path);
+
+                     auto* full_cp_path = gtk_string_object_get_string(preset_path);
+
+                     // Extract package name and preset name from the full path.
+                     const auto cp_info =
+                         self->data->application->presets_manager->get_community_preset_info(preset_type, full_cp_path);
+
+                     // Set labels.
+                     gtk_label_set_text(name, cp_info.first.c_str());
+                     gtk_label_set_text(package, cp_info.second.c_str());
+
+                     // Save community preset package label in try and import buttons.
+                     g_object_set_data(G_OBJECT(try_bt), "gtk-label-package-name", package);
+                     g_object_set_data(G_OBJECT(import), "gtk-label-package-name", package);
+                   }),
+                   self);
+
+  auto refresh_community_listview = +[](GtkButton* button, PresetsMenu* self) {
+    // Empty the list, if it's populated.
+    if (const auto n_items = g_list_model_get_n_items(G_LIST_MODEL(self->presets_list_community)); n_items != 0U) {
+      gtk_string_list_splice(self->presets_list_community, 0U, n_items, nullptr);
+    }
+
+    const auto cp_paths = self->data->application->presets_manager->get_all_community_presets_paths(preset_type);
+
+    // If there are no paths, show the AdwStatusPage and exit.
+    if (cp_paths.empty()) {
+      gtk_widget_set_visible(GTK_WIDGET(self->community_main_box), 0);
+      gtk_widget_set_visible(GTK_WIDGET(self->status_page_community_list), 1);
+
+      return;
+    }
+
+    // If there are paths, fill the empty list and hide the AdwStatusPage.
+    for (const auto& path : cp_paths) {
+      gtk_string_list_append(self->presets_list_community, path.c_str());
+    }
+
+    gtk_widget_set_visible(GTK_WIDGET(self->status_page_community_list), 0);
+    gtk_widget_set_visible(GTK_WIDGET(self->community_main_box), 1);
+  };
+
+  g_signal_connect(self->refresh_community_list, "clicked", G_CALLBACK(refresh_community_listview), self);
+
+  gtk_list_view_set_factory(listview_community, factory);
+
+  g_object_unref(factory);
+
+  // Initialize the list
+  refresh_community_listview(self->refresh_community_list, self);
+}
+
+template <PresetType preset_type>
+void setup_local_presets_listview(PresetsMenu* self, GtkListView* listview_local, GtkStringList* presets_list_local) {
   auto* factory = gtk_signal_list_item_factory_new();
 
   // setting the factory callbacks
@@ -202,19 +381,7 @@ void setup_listview(PresetsMenu* self, GtkListView* listview, GtkStringList* str
                   string_object != nullptr) {
                 auto* preset_name = gtk_string_object_get_string(string_object);
 
-                if constexpr (preset_type == PresetType::output) {
-                  if (self->data->application->presets_manager->load_preset_file(PresetType::output, preset_name)) {
-                    g_settings_set_string(self->settings, "last-used-output-preset", preset_name);
-                  } else {
-                    g_settings_reset(self->settings, "last-used-output-preset");
-                  }
-                } else if constexpr (preset_type == PresetType::input) {
-                  if (self->data->application->presets_manager->load_preset_file(PresetType::input, preset_name)) {
-                    g_settings_set_string(self->settings, "last-used-input-preset", preset_name);
-                  } else {
-                    g_settings_reset(self->settings, "last-used-input-preset");
-                  }
-                }
+                self->data->application->presets_manager->load_local_preset_file(preset_type, preset_name);
               }
             }),
             self);
@@ -274,13 +441,13 @@ void setup_listview(PresetsMenu* self, GtkListView* listview, GtkStringList* str
                   string_object != nullptr) {
                 auto* preset_name = gtk_string_object_get_string(string_object);
 
-                uint operation = GPOINTER_TO_UINT(g_object_get_data(G_OBJECT(button), "operation"));
+                const uint operation = GPOINTER_TO_UINT(g_object_get_data(G_OBJECT(button), "operation"));
 
                 auto* confirmation_label =
                     static_cast<GtkBox*>(g_object_get_data(G_OBJECT(button), "confirmation_label"));
 
                 switch (operation) {
-                  case 0: {  // save
+                  case 0U: {  // save
                     if constexpr (preset_type == PresetType::output) {
                       self->data->application->presets_manager->save_preset_file(PresetType::output, preset_name);
                     } else if constexpr (preset_type == PresetType::input) {
@@ -291,7 +458,7 @@ void setup_listview(PresetsMenu* self, GtkListView* listview, GtkStringList* str
 
                     break;
                   }
-                  case 1: {  // delete
+                  case 1U: {  // delete
                     if constexpr (preset_type == PresetType::output) {
                       self->data->application->presets_manager->remove(PresetType::output, preset_name);
                     } else if constexpr (preset_type == PresetType::input) {
@@ -334,12 +501,12 @@ void setup_listview(PresetsMenu* self, GtkListView* listview, GtkStringList* str
       }),
       self);
 
-  gtk_list_view_set_factory(listview, factory);
+  gtk_list_view_set_factory(listview_local, factory);
 
   g_object_unref(factory);
 
-  for (const auto& name : self->data->application->presets_manager->get_names(preset_type)) {
-    gtk_string_list_append(string_list, name.c_str());
+  for (const auto& name : self->data->application->presets_manager->get_local_presets_name(preset_type)) {
+    gtk_string_list_append(presets_list_local, name.c_str());
   }
 }
 
@@ -354,13 +521,13 @@ void setup(PresetsMenu* self, app::Application* application, PresetType preset_t
       return;
     }
 
-    for (guint n = 0U; n < g_list_model_get_n_items(G_LIST_MODEL(self->string_list)); n++) {
-      if (preset_name == gtk_string_list_get_string(self->string_list, n)) {
+    for (guint n = 0U; n < g_list_model_get_n_items(G_LIST_MODEL(self->presets_list_local)); n++) {
+      if (preset_name == gtk_string_list_get_string(self->presets_list_local, n)) {
         return;
       }
     }
 
-    gtk_string_list_append(self->string_list, preset_name.c_str());
+    gtk_string_list_append(self->presets_list_local, preset_name.c_str());
   };
 
   auto remove_from_list = [=](const std::string& preset_name) {
@@ -370,17 +537,48 @@ void setup(PresetsMenu* self, app::Application* application, PresetType preset_t
       return;
     }
 
-    for (guint n = 0U; n < g_list_model_get_n_items(G_LIST_MODEL(self->string_list)); n++) {
-      if (preset_name == gtk_string_list_get_string(self->string_list, n)) {
-        gtk_string_list_remove(self->string_list, n);
+    for (guint n = 0U; n < g_list_model_get_n_items(G_LIST_MODEL(self->presets_list_local)); n++) {
+      if (preset_name == gtk_string_list_get_string(self->presets_list_local, n)) {
+        gtk_string_list_remove(self->presets_list_local, n);
 
         return;
       }
     }
   };
 
+  auto update_last_used_preset_labels = +[](GSettings* settings, const char* key, gpointer user_data) {
+    auto* self = static_cast<PresetsMenu*>(user_data);
+
+    const std::string preset_name = util::gsettings_get_string(settings, key);
+
+    if (preset_name.empty()) {
+      gtk_widget_set_visible(GTK_WIDGET(self->last_loaded_preset_value), 0);
+
+      gtk_label_set_text(self->last_loaded_preset_value, "");
+      gtk_label_set_text(self->last_loaded_preset_title, _("No Preset Loaded"));
+
+      return;
+    }
+
+    gtk_widget_set_visible(GTK_WIDGET(self->last_loaded_preset_value), 1);
+
+    gtk_label_set_text(self->last_loaded_preset_value, preset_name.c_str());
+
+    const auto* lcp_key = (self->data->preset_type == PresetType::input) ? "last-loaded-input-community-package"
+                                                                         : "last-loaded-output-community-package";
+
+    const std::string community_package = util::gsettings_get_string(settings, lcp_key);
+
+    const std::string preset_title =
+        ((community_package.empty()) ? _("Last Local Preset Loaded") : _("Last Community Preset Loaded"));
+
+    gtk_label_set_text(self->last_loaded_preset_title, preset_title.c_str());
+  };
+
   if (preset_type == PresetType::output) {
-    setup_listview<PresetType::output>(self, self->listview, self->string_list);
+    setup_community_presets_listview<PresetType::output>(self, self->listview_community, self->presets_list_community);
+
+    setup_local_presets_listview<PresetType::output>(self, self->listview_local, self->presets_list_local);
 
     self->data->connections.push_back(
         self->data->application->presets_manager->user_output_preset_created.connect(add_to_list));
@@ -388,38 +586,40 @@ void setup(PresetsMenu* self, app::Application* application, PresetType preset_t
     self->data->connections.push_back(
         self->data->application->presets_manager->user_output_preset_removed.connect(remove_from_list));
 
-    self->data->gconnections.push_back(
-        g_signal_connect(self->settings, "changed::last-used-output-preset",
-                         G_CALLBACK(+[](GSettings* settings, char* key, gpointer user_data) {
-                           auto* self = static_cast<PresetsMenu*>(user_data);
+    self->data->gconnections.push_back(g_signal_connect(self->settings, "changed::last-loaded-output-preset",
+                                                        G_CALLBACK(update_last_used_preset_labels), self));
 
-                           gtk_label_set_text(self->last_used_name, util::gsettings_get_string(settings, key).c_str());
-                         }),
-                         self));
+    // reset last loaded preset label
 
-    gtk_label_set_text(self->last_used_name,
-                       util::gsettings_get_string(self->settings, "last-used-output-preset").c_str());
+    const auto names_output = self->data->application->presets_manager->get_local_presets_name(PresetType::output);
 
-    // reset last used name label
+    const std::string preset_name = util::gsettings_get_string(self->settings, "last-loaded-output-preset");
 
-    const auto names_output = self->data->application->presets_manager->get_names(PresetType::output);
+    bool reset_key = true;
 
-    if (names_output.empty()) {
-      g_settings_set_string(self->settings, "last-used-output-preset", _("Presets"));
+    if (!preset_name.empty()) {
+      for (const auto& name : names_output) {
+        if (name == preset_name) {
+          reset_key = false;
 
-      return;
-    }
-
-    for (const auto& name : names_output) {
-      if (name == util::gsettings_get_string(self->settings, "last-used-output-preset")) {
-        return;
+          break;
+        }
       }
+    } else {
+      reset_key = false;
     }
 
-    g_settings_set_string(self->settings, "last-used-output-preset", _("Presets"));
-
+    if (reset_key) {
+      // reset non-empty key and trigger the changed signal
+      g_settings_reset(self->settings, "last-loaded-output-preset");
+    } else {
+      // no need to reset, just update the labels
+      update_last_used_preset_labels(self->settings, "last-loaded-output-preset", self);
+    }
   } else if (preset_type == PresetType::input) {
-    setup_listview<PresetType::input>(self, self->listview, self->string_list);
+    setup_community_presets_listview<PresetType::input>(self, self->listview_community, self->presets_list_community);
+
+    setup_local_presets_listview<PresetType::input>(self, self->listview_local, self->presets_list_local);
 
     self->data->connections.push_back(
         self->data->application->presets_manager->user_input_preset_created.connect(add_to_list));
@@ -427,35 +627,36 @@ void setup(PresetsMenu* self, app::Application* application, PresetType preset_t
     self->data->connections.push_back(
         self->data->application->presets_manager->user_input_preset_removed.connect(remove_from_list));
 
-    self->data->gconnections.push_back(
-        g_signal_connect(self->settings, "changed::last-used-input-preset",
-                         G_CALLBACK(+[](GSettings* settings, char* key, gpointer user_data) {
-                           auto* self = static_cast<PresetsMenu*>(user_data);
+    self->data->gconnections.push_back(g_signal_connect(self->settings, "changed::last-loaded-input-preset",
+                                                        G_CALLBACK(update_last_used_preset_labels), self));
 
-                           gtk_label_set_text(self->last_used_name, util::gsettings_get_string(settings, key).c_str());
-                         }),
-                         self));
+    // reset last loaded preset label
 
-    gtk_label_set_text(self->last_used_name,
-                       util::gsettings_get_string(self->settings, "last-used-input-preset").c_str());
+    const auto names_input = self->data->application->presets_manager->get_local_presets_name(PresetType::input);
 
-    // reset last used name label
+    const std::string preset_name = util::gsettings_get_string(self->settings, "last-loaded-input-preset");
 
-    const auto names_input = self->data->application->presets_manager->get_names(PresetType::input);
+    bool reset_key = true;
 
-    if (names_input.empty()) {
-      g_settings_set_string(self->settings, "last-used-input-preset", _("Presets"));
+    if (!preset_name.empty()) {
+      for (const auto& name : names_input) {
+        if (name == preset_name) {
+          reset_key = false;
 
-      return;
-    }
-
-    for (const auto& name : names_input) {
-      if (name == util::gsettings_get_string(self->settings, "last-used-input-preset")) {
-        return;
+          break;
+        }
       }
+    } else {
+      reset_key = false;
     }
 
-    g_settings_set_string(self->settings, "last-used-input-preset", _("Presets"));
+    if (reset_key) {
+      // reset non-empty key and trigger the changed signal
+      g_settings_reset(self->settings, "last-loaded-input-preset");
+    } else {
+      // no need to reset, just update the labels
+      update_last_used_preset_labels(self->settings, "last-loaded-input-preset", self);
+    }
   }
 }
 
@@ -468,7 +669,7 @@ void show(GtkWidget* widget) {
 
   const int menu_height = static_cast<int>(0.5F * static_cast<float>(active_window_height));
 
-  gtk_scrolled_window_set_max_content_height(self->scrolled_window, menu_height);
+  gtk_scrolled_window_set_max_content_height(self->scrolled_window_local, menu_height);
 
   GTK_WIDGET_CLASS(presets_menu_parent_class)->show(widget);
 }
@@ -515,15 +716,25 @@ void presets_menu_class_init(PresetsMenuClass* klass) {
 
   gtk_widget_class_set_template_from_resource(widget_class, tags::resources::presets_menu_ui);
 
-  gtk_widget_class_bind_template_child(widget_class, PresetsMenu, string_list);
+  gtk_widget_class_bind_template_child(widget_class, PresetsMenu, presets_list_local);
+  gtk_widget_class_bind_template_child(widget_class, PresetsMenu, presets_list_community);
 
-  gtk_widget_class_bind_template_child(widget_class, PresetsMenu, scrolled_window);
-  gtk_widget_class_bind_template_child(widget_class, PresetsMenu, listview);
-  gtk_widget_class_bind_template_child(widget_class, PresetsMenu, name);
-  gtk_widget_class_bind_template_child(widget_class, PresetsMenu, last_used_name);
+  gtk_widget_class_bind_template_child(widget_class, PresetsMenu, scrolled_window_local);
+  gtk_widget_class_bind_template_child(widget_class, PresetsMenu, scrolled_window_community);
+  gtk_widget_class_bind_template_child(widget_class, PresetsMenu, new_preset_name);
+  gtk_widget_class_bind_template_child(widget_class, PresetsMenu, search_community);
+  gtk_widget_class_bind_template_child(widget_class, PresetsMenu, filter_string_community);
+  gtk_widget_class_bind_template_child(widget_class, PresetsMenu, listview_local);
+  gtk_widget_class_bind_template_child(widget_class, PresetsMenu, listview_community);
+  gtk_widget_class_bind_template_child(widget_class, PresetsMenu, community_main_box);
+  gtk_widget_class_bind_template_child(widget_class, PresetsMenu, status_page_community_list);
+  gtk_widget_class_bind_template_child(widget_class, PresetsMenu, refresh_community_list);
+  gtk_widget_class_bind_template_child(widget_class, PresetsMenu, last_loaded_preset_title);
+  gtk_widget_class_bind_template_child(widget_class, PresetsMenu, last_loaded_preset_value);
 
   gtk_widget_class_bind_template_callback(widget_class, create_preset);
-  gtk_widget_class_bind_template_callback(widget_class, import_preset);
+  gtk_widget_class_bind_template_callback(widget_class, import_preset_from_disk);
+  gtk_widget_class_bind_template_callback(widget_class, closure_community_search_filter);
 }
 
 void presets_menu_init(PresetsMenu* self) {
