@@ -159,7 +159,7 @@ void on_import_model_clicked(RNNoiseBox* self, GtkButton* btn) {
   gtk_file_dialog_set_title(dialog, _("Import Model File"));
   gtk_file_dialog_set_accept_label(dialog, _("Open"));
 
-  auto* init_folder = g_file_new_for_path(SYSTEM_RNNOISE_DIR);
+  auto* init_folder = g_file_new_for_path(g_get_home_dir());
 
   gtk_file_dialog_set_initial_folder(dialog, init_folder);
 
@@ -170,7 +170,7 @@ void on_import_model_clicked(RNNoiseBox* self, GtkButton* btn) {
   auto* filter = gtk_file_filter_new();
 
   gtk_file_filter_set_name(filter, _("RNNoise Models"));
-  gtk_file_filter_add_pattern(filter, "*.rnnn");
+  gtk_file_filter_add_pattern(filter, ("*"s + rnnn_ext).c_str());
 
   g_list_store_append(filters, filter);
 
@@ -210,8 +210,8 @@ void setup_listview(RNNoiseBox* self) {
     gtk_string_list_append(self->string_list, name.c_str());
   }
 
-  if (g_list_model_get_n_items(G_LIST_MODEL(self->string_list)) == 0) {
-    g_settings_set_string(self->settings, "model-path", "");
+  if (g_list_model_get_n_items(G_LIST_MODEL(self->string_list)) == 0U) {
+    g_settings_reset(self->settings, "model-name");
   }
 }
 
@@ -235,7 +235,7 @@ void setup(RNNoiseBox* self,
   rnnoise->set_post_messages(true);
 
   // Initialize state labels
-  if (const auto m = util::gsettings_get_string(self->settings, "model-path"); !m.empty() && rnnoise->standard_model) {
+  if (const auto m = util::gsettings_get_string(self->settings, "model-name"); !m.empty() && rnnoise->standard_model) {
     update_model_state(self, true);
   }
 
@@ -291,36 +291,68 @@ void setup(RNNoiseBox* self,
       self->settings, self->input_gain, self->output_gain, self->enable_vad, self->vad_thres, self->wet, self->release);
 
   g_settings_bind_with_mapping(
-      self->settings, "model-path", self->selection_model, "selected", G_SETTINGS_BIND_DEFAULT,
+      self->settings, "model-name", self->selection_model, "selected", G_SETTINGS_BIND_DEFAULT,
       +[](GValue* value, GVariant* variant, gpointer user_data) {
         auto* self = EE_RNNOISE_BOX(user_data);
 
-        const auto* v = g_variant_get_string(variant, nullptr);
-
-        const auto path = std::filesystem::path{v};
-
         const std::string default_model_name = _("Standard Model");
 
-        auto gsettings_model_name = path.stem();
+        const std::string gsettings_model_name = g_variant_get_string(variant, nullptr);
 
+        const auto* lcp_key = (self->data->rnnoise->pipeline_type == PipelineType::input)
+                                  ? "last-loaded-input-community-package"
+                                  : "last-loaded-output-community-package";
+
+        const auto community_package = util::gsettings_get_string(self->data->application->settings, lcp_key);
+
+        if (!community_package.empty()) {
+          // Model from community package used, so unselect the selection.
+          g_value_set_uint(value, GTK_INVALID_LIST_POSITION);
+
+          // Since no item is selected, we set the community model name in
+          // the active_model_name label manually.
+          gtk_label_set_text(self->active_model_name, gsettings_model_name.c_str());
+
+          return 1;
+        }
+
+        // Local model used.
         int standard_model_id = 0;
 
         for (guint n = 0U; n < g_list_model_get_n_items(G_LIST_MODEL(self->selection_model)); n++) {
           auto item = g_list_model_get_item(G_LIST_MODEL(self->selection_model), n);
 
-          const std::string model_name = gtk_string_object_get_string(GTK_STRING_OBJECT(item));
+          auto* string_object = GTK_STRING_OBJECT(item);
+
+          if (string_object == nullptr) {
+            continue;
+          }
+
+          const std::string model_name = gtk_string_object_get_string(string_object);
 
           g_object_unref(item);
 
           if (gsettings_model_name == model_name) {
+            // Select the local model and exit.
             g_value_set_uint(value, n);
+
+            return 1;
           } else if (model_name == default_model_name) {
+            // Save the position of the standard model.
             standard_model_id = n;
           }
         }
 
         if (gsettings_model_name.empty()) {
+          // If the model name is empty, select the standard model.
           g_value_set_uint(value, standard_model_id);
+        } else {
+          // A local preset is loaded, but the model file on the filesystem is missing.
+          // Unselect the selection.
+          g_value_set_uint(value, GTK_INVALID_LIST_POSITION);
+
+          // Update the active_model_name anyway.
+          gtk_label_set_text(self->active_model_name, gsettings_model_name.c_str());
         }
 
         return 1;
@@ -328,20 +360,23 @@ void setup(RNNoiseBox* self,
       +[](const GValue* value, const GVariantType* expected_type, gpointer user_data) {
         auto* self = EE_RNNOISE_BOX(user_data);
 
+        const auto* lcp_key = (self->data->rnnoise->pipeline_type == PipelineType::input)
+                                  ? "last-loaded-input-community-package"
+                                  : "last-loaded-output-community-package";
+
+        // models loaded from the rnnoise ui are always local.
+        g_settings_reset(self->data->application->settings, lcp_key);
+
         auto string_object =
             GTK_STRING_OBJECT(gtk_single_selection_get_selected_item(GTK_SINGLE_SELECTION(self->selection_model)));
 
-        const std::string name = gtk_string_object_get_string(string_object);
+        const std::string selected_name = (string_object != nullptr) ? gtk_string_object_get_string(string_object) : "";
 
         const std::string default_model_name = _("Standard Model");
 
-        if (name == default_model_name) {
-          return g_variant_new_string("");
-        }
+        const std::string gsettings_model_name = (selected_name == default_model_name) ? "" : selected_name;
 
-        const auto model_file = model_dir / std::filesystem::path{name + rnnn_ext};
-
-        return g_variant_new_string(model_file.c_str());
+        return g_variant_new_string(gsettings_model_name.c_str());
       },
       self, nullptr);
 }
@@ -431,25 +466,15 @@ void rnnoise_box_init(RNNoiseBox* self) {
 
   prepare_scales<"dB">(self->input_gain, self->output_gain);
 
-  prepare_spinbutton<"ms">(self->release);
+  prepare_spinbuttons<"ms">(self->release);
 
-  prepare_spinbutton<"%">(self->vad_thres);
+  prepare_spinbuttons<"%">(self->vad_thres);
 
   // The following spinbuttons can assume -inf
   prepare_spinbuttons<"dB", false>(self->wet);
 
   // model dir
 
-  if (!std::filesystem::is_directory(model_dir)) {
-    if (std::filesystem::create_directories(model_dir)) {
-      util::debug("model directory created: " + model_dir.string());
-    } else {
-      util::warning("failed to create model directory: " + model_dir.string());
-    }
-  } else {
-    util::debug("model directory already exists: " + model_dir.string());
-  }
-
   auto gfile = g_file_new_for_path(model_dir.c_str());
 
   self->folder_monitor = g_file_monitor_directory(gfile, G_FILE_MONITOR_NONE, nullptr, nullptr);
