@@ -1,5 +1,5 @@
 /*
- *  Copyright © 2017-2023 Wellington Wallace
+ *  Copyright © 2017-2024 Wellington Wallace
  *
  *  This file is part of Easy Effects.
  *
@@ -18,6 +18,13 @@
  */
 
 #include "tags_plugin_name.hpp"
+#include <glib/gi18n.h>
+#include <sys/types.h>
+#include <map>
+#include <regex>
+#include <string>
+#include <string_view>
+#include "util.hpp"
 
 namespace {
 
