@@ -18,6 +18,7 @@
  */
 
 #include "util.hpp"
+#include "pipe_manager.hpp"
 #include <gdk/gdk.h>
 #include <gio/gio.h>
 #include <gio/gsettingsschema.h>
@@ -313,6 +314,11 @@ void idle_add(std::function<void()> cb, std::function<void()> cleanup_cb) {
                      return G_SOURCE_REMOVE;
                    }
 
+                   if (PipeManager::exiting) {
+                     delete d;
+                     return G_SOURCE_REMOVE;
+                   }
+
                    if (d->cb == nullptr) {
                      return G_SOURCE_REMOVE;
                    }
